==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotConfigurationDescriptionMetadata } from "./WebPivotConfigurationDescriptionMetadata";
import { WebPivotConfigurationChangedEventArgsDetailDescription } from "./WebPivotConfigurationChangedEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.a == null) {
                WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.c(WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.a);
            WebPivotConfigurationDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotConfigurationChangedEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("PivotConfiguration", "ExportedType:WebPivotConfiguration");
        }
        static d(a) {
            WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebPivotConfigurationChangedEventArgsDetail", () => new WebPivotConfigurationChangedEventArgsDetailDescription());
            a.ac("WebPivotConfigurationChangedEventArgsDetail", WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.$t = markType(WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata, 'WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata');
    WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.a = null;
    return WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotConfigurationDescriptionMetadata } from "./WebPivotConfigurationDescriptionMetadata";
import { WebPivotConfigurationChangedEventArgsDetailDescription } from "./WebPivotConfigurationChangedEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.a == null) {
                WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.c(WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.a);
            WebPivotConfigurationDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotConfigurationChangedEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("PivotConfiguration", "ExportedType:WebPivotConfiguration");
        }
        static d(a) {
            WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebPivotConfigurationChangedEventArgsDetail", () => new WebPivotConfigurationChangedEventArgsDetailDescription());
            a.ad("WebPivotConfigurationChangedEventArgsDetail", WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.$t = markType(WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata, 'WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata');
    WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata.a = null;
    return WebPivotConfigurationChangedEventArgsDetailDescriptionMetadata;
})();
